Learn R Programming

finto (version 0.1.1)

get_alphabetical_index_letters: Get the initial letters of the alphabetical index for labels in a specific vocabulary from the Finto Skosmos API

Description

Get the initial letters of the alphabetical index for labels in a specific vocabulary from the Finto Skosmos API

Usage

get_alphabetical_index_letters(vocid, lang = NULL)

Value

A tibble containing the initial letters of the alphabetical index.

Arguments

vocid

The vocabulary ID, e.g., "yso".

lang

The language of labels, e.g., "en" or "fi". Optional.

Examples

Run this code
result <- get_alphabetical_index_letters(vocid = "yso", lang = "fi")
print(result)

Run the code above in your browser using DataLab