Learn R Programming

finto (version 0.1.1)

get_concept_labels_vocid: Get labels for a specific concept from the Finto Skosmos API

Description

Get labels for a specific concept from the Finto Skosmos API

Usage

get_concept_labels_vocid(vocid, uri, lang = NULL)

Value

A tibble containing the labels (prefLabel, altLabel, hiddenLabel) for the specified concept.

Arguments

vocid

The vocabulary ID, e.g., "yso".

uri

The URI of the concept whose labels to retrieve.

lang

The language code for the labels, e.g., "fi" or "en". Optional.

Examples

Run this code
lables <- get_concept_labels_vocid(vocid = "yso",
uri = "http://www.yso.fi/onto/yso/p22922", lang = "fi")
print(lables)

Run the code above in your browser using DataLab