Learn R Programming

finto (version 0.1.1)

get_concepts_by_letter: Get concepts starting with a specific letter in the alphabetical index for a given vocabulary

Description

Get concepts starting with a specific letter in the alphabetical index for a given vocabulary

Usage

get_concepts_by_letter(vocid, letter, lang = NULL)

Value

A tibble containing concepts with labels starting with the given letter.

Arguments

vocid

The vocabulary ID, e.g., "yso".

letter

The initial letter, or "0-9" for numeric or "!*" for special character labels.

lang

The language of labels, e.g., "en" or "fi". Optional.

Examples

Run this code
result <- get_concepts_by_letter(vocid = "yso", letter = "A", lang = "fi")
print(result)

Run the code above in your browser using DataLab