Get modified concepts in a specific vocabulary from the Finto Skosmos API
Source:R/get_modified_concepts.R
get_modified_concepts.RdGet modified concepts in a specific vocabulary from the Finto Skosmos API
Examples
result <- get_modified_concepts(vocid = "yso", lang = "fi", limit = 10)
#> Requesting URL: https://api.finto.fi/rest/v1/yso/modified?lang=fi&limit=10
print(result)
#> # A tibble: 10 × 3
#> uri prefLabel date
#> <chr> <chr> <chr>
#> 1 http://www.yso.fi/onto/yso/p1012 ajokaskasvit 2026-07-03T12:29:52+0300
#> 2 http://www.yso.fi/onto/yso/p41250 araneesi 2026-07-01T12:32:02+0300
#> 3 http://www.yso.fi/onto/yso/p41242 arat 2026-07-01T12:33:57+0300
#> 4 http://www.yso.fi/onto/yso/p12711 freesiat 2026-07-03T12:38:24+0300
#> 5 http://www.yso.fi/onto/yso/p21083 hapatteet 2026-07-07T09:58:45+0300
#> 6 http://www.yso.fi/onto/yso/p967 hautaus 2026-07-01T11:31:28+0300
#> 7 http://www.yso.fi/onto/yso/p2569 heinäkasvit 2026-07-03T12:32:13+0300
#> 8 http://www.yso.fi/onto/yso/p41296 helppo ruoanlaitto 2026-07-01T12:36:29+0300
#> 9 http://www.yso.fi/onto/yso/p7042 kaislat 2026-07-03T12:52:59+0300
#> 10 http://www.yso.fi/onto/yso/p4949 kertaustyylit 2026-07-01T12:07:29+0300