Get new concepts in a specific vocabulary from the Finto Skosmos API
Source:R/get_new_concepts.R
get_new_concepts.RdGet new concepts in a specific vocabulary from the Finto Skosmos API
Examples
result <- get_new_concepts(vocid = "yso", lang = "fi", limit = 10)
#> Requesting URL: https://api.finto.fi/rest/v1/yso/new?lang=fi&limit=10
print(result)
#> # A tibble: 10 × 3
#> uri prefLabel date
#> <chr> <chr> <chr>
#> 1 http://www.yso.fi/onto/yso/p15091 alustat 2026-06-25T11:21:00+0…
#> 2 http://www.yso.fi/onto/yso/p15091 alustat 2026-06-25T11:21:00+0…
#> 3 http://www.yso.fi/onto/yso/p41250 araneesi 2026-06-15T16:04:33+0…
#> 4 http://www.yso.fi/onto/yso/p41242 arat 2026-06-15T13:49:58+0…
#> 5 http://www.yso.fi/onto/yso/p41246 arkkiatrit 2026-06-15T15:51:27+0…
#> 6 http://www.yso.fi/onto/yso/p23444 Augsburgin tunnustus 2026-06-30T12:09:21+0…
#> 7 http://www.yso.fi/onto/yso/p41283 avoin suhde 2026-06-18T10:35:01+0…
#> 8 http://www.yso.fi/onto/yso/p41301 biofortifikaatio 2026-06-18T14:05:30+0…
#> 9 http://www.yso.fi/onto/yso/p41264 brakyterapia 2026-06-16T12:59:50+0…
#> 10 http://www.yso.fi/onto/yso/p41277 brunettet 2026-06-18T10:04:43+0…