Learn R Programming

finto (version 0.1.1)

get_vocabulary_info: Get general information about a specific vocabulary from the Finto Skosmos API

Description

Get general information about a specific vocabulary from the Finto Skosmos API

Usage

get_vocabulary_info(vocid, lang = NULL)

Value

A list containing the vocabulary details such as URI, title, languages, and concept schemes.

Arguments

vocid

The vocabulary ID, e.g., "yso".

lang

The language of labels to retrieve, e.g., "en" or "fi". Optional.

Examples

Run this code
result <- get_vocabulary_info(vocid = "yso", lang = "fi")
print(result)

Run the code above in your browser using DataLab