Get vocabulary statistics as a single tibble containing concepts, subtypes, and concept groups
Source:R/get_vocabulary_statistics.R
get_vocabulary_statistics.RdGet vocabulary statistics as a single tibble containing concepts, subtypes, and concept groups
Value
A tibble containing counts of concepts, subtypes, and concept groups, with each entry in one row.
Examples
result <- get_vocabulary_statistics(vocid = "yso", lang = "fi")
#> Requesting URL: https://api.finto.fi/rest/v1/yso/vocabularyStatistics?lang=fi
print(result)
#> # A tibble: 7 × 5
#> category class label count deprecatedCount
#> <chr> <chr> <chr> <int> <int>
#> 1 Concepts NA NA NA NA
#> 2 SubTypes http://www.yso.fi/onto/yso-meta/Hie… Hier… 79 0
#> 3 SubTypes http://www.yso.fi/onto/yso-meta/Work Teos 3 0
#> 4 SubTypes http://www.yso.fi/onto/yso-meta/Cor… Yhte… 7 0
#> 5 SubTypes http://www.yso.fi/onto/yso-meta/Ind… Yksi… 821 0
#> 6 SubTypes http://www.yso.fi/onto/yso-meta/Con… Ylei… 30596 4
#> 7 ConceptGroups http://www.w3.org/2004/02/skos/core… Koko… 242 56