powered by
Get the initial letters of the alphabetical index for labels in a specific vocabulary from the Finto Skosmos API
get_alphabetical_index_letters(vocid, lang = NULL)
A tibble containing the initial letters of the alphabetical index.
The vocabulary ID, e.g., "yso".
The language of labels, e.g., "en" or "fi". Optional.
result <- get_alphabetical_index_letters(vocid = "yso", lang = "fi") print(result)
Run the code above in your browser using DataLab