powered by
Get concepts starting with a specific letter in the alphabetical index for a given vocabulary
get_concepts_by_letter(vocid, letter, lang = NULL)
A tibble containing concepts with labels starting with the given letter.
The vocabulary ID, e.g., "yso".
The initial letter, or "0-9" for numeric or "!*" for special character labels.
The language of labels, e.g., "en" or "fi". Optional.
result <- get_concepts_by_letter(vocid = "yso", letter = "A", lang = "fi") print(result)
Run the code above in your browser using DataLab