powered by
Get general information about a specific vocabulary from the Finto Skosmos API
get_vocabulary_info(vocid, lang = NULL)
A list containing the vocabulary details such as URI, title, languages, and concept schemes.
The vocabulary ID, e.g., "yso".
The language of labels to retrieve, e.g., "en" or "fi". Optional.
result <- get_vocabulary_info(vocid = "yso", lang = "fi") print(result)
Run the code above in your browser using DataLab