Learn R Programming

finto (version 0.1.1)

get_vocabulary_statistics: Get vocabulary statistics as a single tibble containing concepts, subtypes, and concept groups

Description

Get vocabulary statistics as a single tibble containing concepts, subtypes, and concept groups

Usage

get_vocabulary_statistics(vocid, lang = NULL)

Value

A tibble containing counts of concepts, subtypes, and concept groups, with each entry in one row.

Arguments

vocid

The vocabulary ID, e.g., "yso".

lang

The language of labels, e.g., "en" or "fi". Optional.

Examples

Run this code
result <- get_vocabulary_statistics(vocid = "yso", lang = "fi")
print(result)

Run the code above in your browser using DataLab