powered by
Get vocabulary statistics as a single tibble containing concepts, subtypes, and concept groups
get_vocabulary_statistics(vocid, lang = NULL)
A tibble containing counts of concepts, subtypes, and concept groups, with each entry in one row.
The vocabulary ID, e.g., "yso".
The language of labels, e.g., "en" or "fi". Optional.
result <- get_vocabulary_statistics(vocid = "yso", lang = "fi") print(result)
Run the code above in your browser using DataLab