Learn R Programming

finto (version 0.1.1)

lookup_concept_by_label: Look up concepts by label in a specific vocabulary from the Finto Skosmos API

Description

Look up concepts by label in a specific vocabulary from the Finto Skosmos API

Usage

lookup_concept_by_label(vocid, label, lang = NULL)

Value

A tibble containing the best matching concept(s) with fields like uri, type, prefLabel, and altLabel.

Arguments

vocid

The vocabulary ID, e.g., "yso".

label

The label to look up, e.g., "cat".

lang

The search language, e.g., "en" or "fi". Optional.

Examples

Run this code
result <- lookup_concept_by_label(vocid = "yso", label = "cat", lang = "en")
print(result)

Run the code above in your browser using DataLab