Learn R Programming

finto (version 0.1.1)

search_vocabulary_concepts: Search for concepts and collections in a specific vocabulary from the Finto Skosmos API

Description

Search for concepts and collections in a specific vocabulary from the Finto Skosmos API

Usage

search_vocabulary_concepts(
  vocid,
  query,
  lang = NULL,
  type = NULL,
  maxhits = NULL,
  offset = NULL
)

Value

A tibble containing the search results with fields such as uri, type, prefLabel, and altLabel.

Arguments

vocid

The vocabulary ID, e.g., "yso".

query

The search term, e.g., "cat*".

lang

The language of labels to match, e.g., "en" or "fi". Optional.

type

Limit search to concepts of a given type, e.g., "skos:Concept". Optional.

maxhits

Maximum number of results to return. Optional.

offset

Offset where to start in the result set, useful for paging. Optional.

Examples

Run this code
search_results <- search_vocabulary_concepts(vocid = "yso", query = "cat", lang = "en")
print(search_results)

Run the code above in your browser using DataLab