powered by
Search for concepts and collections in a specific vocabulary from the Finto Skosmos API
search_vocabulary_concepts( vocid, query, lang = NULL, type = NULL, maxhits = NULL, offset = NULL )
A tibble containing the search results with fields such as uri, type, prefLabel, and altLabel.
The vocabulary ID, e.g., "yso".
The search term, e.g., "cat*".
The language of labels to match, e.g., "en" or "fi". Optional.
Limit search to concepts of a given type, e.g., "skos:Concept". Optional.
Maximum number of results to return. Optional.
Offset where to start in the result set, useful for paging. Optional.
search_results <- search_vocabulary_concepts(vocid = "yso", query = "cat", lang = "en") print(search_results)
Run the code above in your browser using DataLab